
// NEOPIXEL BEST PRACTICES for most reliable operation:
// - Add 1000 uF CAPACITOR between NeoPixel strip's + and - connections.
// - MINIMIZE WIRING LENGTH between microcontroller board and first pixel.
// - NeoPixel strip's DATA-IN should pass through a 300-500 OHM RESISTOR.
// - AVOID connecting NeoPixels on a LIVE CIRCUIT. If you must, ALWAYS
//   connect GROUND (-) first, then +, then data.
// - When using a 3.3V microcontroller with a 5V-powered NeoPixel strip,
//   a LOGIC-LEVEL CONVERTER on the data line is STRONGLY RECOMMENDED.
// (Skipping these may work OK on your workbench but can fail in the field)

#include <Adafruit_NeoPixel.h>

#define LED_PIN    6 //Pin, an dem DIN der Matrix angeschlossen ist

#define LED_ANZAHL 16 //Anzahl der LEDs in dem "Streifen"

// Deklaration des Objektes Neopixel-Streifen (Klasse):
Adafruit_NeoPixel Streifen(LED_ANZAHL, LED_PIN, NEO_GRB + NEO_KHZ800);
// erster Parameter = Anzahl der LEDs im Streifen
// zweiter Parameter = ARDUINO Pin für DIN (die meisten Pins können hier verwendet werden)
// dritter Parameter = Pixel type flags (hier werden die einzelnen Bit-Flags addiert):
//   NEO_KHZ800  800 KHz bitstream (die meisten NeoPixel- Produkte mit WS2812 LEDs können so schnell betrieben werden - s. Datenblatt)
//   NEO_KHZ400  400 KHz (für die klassischen 'V1' (nicht V2) FLORA pixels, WS2811 Treiber)
//   NEO_GRB     Reihenfolge für die Datenreihenfolge der LED (WS2812)
//   NEO_RGB     Reihenfolge für die Datenreihenfolge der LED (WS2811 oder V1 FLORA pixels, nicht V2)
//   NEO_RGBW    Reihenfolge für die Datenreihenfolge der LED (WS2812 mit zusätzlicher weißer LED RGBW )




void setup() {

  Streifen.begin();           // Initialisierung des Neopixel Objekts (NOTWENDIG)
  Streifen.show();            // Alle LEDs schnell dunkel schalten
  Streifen.setBrightness(50); // Setzen der Helligkeit der LEDs. 1/5 ist ein guter Wert. Merke je höher der Wert, desto mehr Strom wird verbraucht (max 255)
}


// loop() function -- runs repeatedly as long as board is on ---------------

void loop() {
  Farbverlauf(20);             // Farbverlauf über jede einzelne LED
}


void Farbverlauf(int Pause) {
 for(long esterFarbton = 0; esterFarbton < 65536; esterFarbton += 64) {
   //Streifen.rainbow(esterFarbton, LED_ANZAHL);
   Streifen.rainbow(esterFarbton, 1);
   Streifen.show(); // Den Streifen mit neuen Werten setzen
   delay(Pause);  // Warten auf den nächsten Durchlauf
  }
}

